_antonyms = {
    "fähigkeit": "unfähigkeit",
    "abnormal": "normal",
    "abschaffen": "gründen",
    "abwesenheit": "gegenwart",
    "abwesend": "geschenk",
    "zukunft": "vergangenheit",
    "absolut": "relativ",
    "verzichten": "verbrauchen",
    "abstrakt": "beton",
    "fülle": "leere",
    "reichlich": "knapp",
    "akzeptieren": "ablehnen",
    "eingestehen": "verweigern",
    "akzeptabel": "inakzeptabel",
    "annahme": "ablehnung",
    "zugänglich": "nicht zugänglich",
    "genau": "ungenau",
    "anerkannt": "unbestätigt",
    "bekanntschaft": "fremder",
    "handlung": "refrain",
    "aktion": "untätigkeit",
    "aktiv": "ruhig",
    "vorhanden": "ausgestorben",
    "laut": "ruhig",
    "aktivität": "inaktivität",
    "tatsächlich": "potenzial",
    "hinzufügen": "subtrahieren",
    "zusatz": "subtraktion",
    "angemessene": "unzureichend",
    "adjektiv": "substantiv",
    "zulässig": "unzulässig",
    "erwachsene": "jugendlich",
    "voraus": "zurücktreten",
    "voraus": "erfolgreich",
    "vorderseite": "rückseite",
    "veer": "zurück",
    "vorteil": "nachteil",
    "bejahung": "umkehrung",
    "positiv": "negativ",
    "neutral": "negativ",
    "achtern": "vordergrund",
    "alter": "verjüngen",
    "alt": "jung",
    "agitation": "ruhe",
    "zustimmen": "nicht zustimmen",
    "angenehm": "unangenehm",
    "zustimmung": "dissens",
    "verändert": "unverändert",
    "wechseln": "gegenteil",
    "amateur": "professionel",
    "mehrdeutig": "eindeutig",
    "freundschaftlich": "feindlich",
    "freundlich": "unfreundlich",
    "amphibisch": "terrestrisch",
    "anal": "oral",
    "analog": "homolog",
    "analyse": "synthese",
    "analytisch": "synthetik",
    "vorfahr": "nachkomme",
    "winkel": "gerundet",
    "animieren": "unbelebt",
    "antworten": "frage",
    "antagonistisch": "synergistisch",
    "antecedent": "anschließend",
    "anterior": "hintere",
    "antiseptikum": "septisch",
    "aussehen": "verschwinden",
    "anerkennung": "abschreibung",
    "die genehmigung": "missbilligung",
    "genehmigen": "missbilligen",
    "wasser-": "amphibisch",
    "terrestrisch": "amphibisch",
    "wässrig": "magmatisch",
    "arm": "entwaffnen",
    "bewaffnet": "unbewaffnet",
    "ankommen": "verlassen",
    "aufsteigen": "absteigen",
    "aufstieg": "abstammung",
    "schlafend": "erwachen",
    "asymmetrie": "symmetrie",
    "atheismus": "theismus",
    "anfügen": "ablösen",
    "attacke": "verteidigen",
    "strafrechtlich verfolgen": "verteidigen",
    "beachtung": "unaufmerksamkeit",
    "attraktion": "abstoßung",
    "hörbar": "unverständlich",
    "augmentation": "verminderung",
    "tante": "onkel",
    "autorisiert": "nicht autorisiert",
    "automatisch": "handbuch",
    "vermeiden": "konfrontieren",
    "erwachen": "schlafend",
    "zurück": "veer",
    "zurücktreten": "voraus",
    "rückseite": "kopf",
    "hintergrund": "vordergrund",
    "rückwärts": "nach vorne",
    "umkehren": "vorderseite",
    "schlecht": "gut",
    "böse": "tugendhaft",
    "schlechtigkeit": "güte",
    "ausgewogen": "unausgeglichen",
    "bär": "stier",
    "schön": "hässlich",
    "schönheit": "hässlichkeit",
    "start": "ende",
    "anfang": "halt",
    "früh": "spät",
    "glauben": "unglaube",
    "biege": "begradigen",
    "gutartig": "maligne",
    "groß": "klein",
    "geburt": "tod",
    "bisexuell": "homosexuell",
    "schwarz": "weiß",
    "segnen": "fluch",
    "gesegnet": "verflucht",
    "unblutig": "blutig",
    "blutig": "unblutig",
    "verwischen": "fokus",
    "kochen": "einfrieren",
    "fett gedruckt": "schüchtern",
    "mut": "feigheit",
    "leihen": "verleihen",
    "kreditnehmer": "darlehensgeber",
    "unterseite": "oben",
    "gebunden": "ungebunden",
    "junge": "mädchen",
    "boykott": "bevormunden",
    "unterbrechung": "reparatur",
    "zerbrechlich": "unzerbrechlich",
    "aufhellen": "verdunkeln",
    "erleichtern": "verdunkeln",
    "gebrochen": "ungebrochen",
    "bruder": "schwester",
    "stier": "bär",
    "beschäftigt": "leerlauf",
    "arbeit": "leerlauf",
    "kaufen": "verkaufen",
    "ruhe": "agitation",
    "fähig": "unfähig",
    "kapazität": "unfähigkeit",
    "kasse": "kredit",
    "lastschrift": "kredit",
    "center": "links",
    "zerebral": "emotional",
    "sicherheit": "unsicherheit",
    "veränderung": "bleibe",
    "abfahren": "bleibe",
    "bewegung": "bleibe",
    "veränderbar": "unveränderlich",
    "geändert": "unverändert",
    "aufladen": "entladen",
    "gewinnen": "verlust",
    "billig": "teuer",
    "jubeln": "beschweren",
    "heiter": "deprimierend",
    "kind": "elternteil",
    "zivilist": "militär-",
    "anspruch": "einbüßen",
    "klarheit": "opazität",
    "bedeutung": "bedeutungslosigkeit",
    "transparenz": "opazität",
    "reinigen": "unrein",
    "klerus": "laien",
    "geistliche": "laie",
    "schließen": "öffnen",
    "geschlossen": "öffnen",
    "nähe": "offenheit",
    "küsten": "inland",
    "kohärent": "inkohärent",
    "kalt": "heiß",
    "komödie": "tragödie",
    "komfort": "beschwerden",
    "verbreitet": "ungewöhnlich",
    "kompatibel": "unvereinbar",
    "kompetenz": "inkompetenz",
    "kompetent": "inkompetent",
    "wettbewerb": "zusammenarbeit",
    "beschweren": "jubeln",
    "vollständigkeit": "unvollständigkeit",
    "komplex": "einfach",
    "verbindung": "einfach",
    "konform": "trotzig",
    "komplizieren": "vereinfachen",
    "konkav": "konvex",
    "einbildung": "demut",
    "stolz": "demut",
    "konzentration": "verteilung",
    "konzentrisch": "exzenter",
    "konzeption": "missverständnis",
    "besorgt": "unbekümmert",
    "beton": "abstrakt",
    "bestätigt": "unbestätigt",
    "konfrontieren": "vermeiden",
    "konjunktiv": "disjunkt",
    "verbinden": "trennen",
    "in verbindung gebracht": "unverbunden",
    "bewusstsein": "bewusstlosigkeit",
    "konservativ": "liberale",
    "sparen": "abfall",
    "rücksichtsvoll": "rücksichtslos",
    "konsistenz": "inkonsistenz",
    "konsonant": "vokal",
    "auffällig": "unauffällig",
    "konstitutionelle": "verfassungswidrig",
    "verbrauchen": "verzichten",
    "inhalt": "unzufriedenheit",
    "kontinuierlich": "diskontinuierlich",
    "bestand": "einstellung",
    "fortsetzen": "abbrechen",
    "kontinuität": "diskontinuität",
    "vertrag": "erweitern",
    "vertrag abgeschlossen": "erweitert",
    "kontraktion": "erweiterung",
    "praktisch": "ungünstig",
    "konventionell": "unkonventionell",
    "konvergieren": "divergieren",
    "konvergenz": "abweichungen",
    "konvergent": "abweichend",
    "konvex": "konkav",
    "überzeugt": "nicht überzeugt",
    "cool": "hitze",
    "zusammenarbeit": "wettbewerb",
    "kosmopolitisch": "provinziell",
    "abdeckung": "aufdecken",
    "verdeckt": "offen",
    "feigheit": "mut",
    "kredit": "lastschrift",
    "gläubiger": "schuldner",
    "kritisieren": "loben",
    "schrei": "lachen",
    "heilbar": "unheilbar",
    "fluch": "segnen",
    "verflucht": "gesegnet",
    "gebogen": "gerade",
    "schnitt": "ungeschnitten",
    "achtung": "sicherheit",
    "gefährlich": "sicher",
    "dunkel": "licht",
    "verdunkeln": "erleichtern",
    "dunkelheit": "bedeutung",
    "schwere": "leichtigkeit",
    "tochter": "sohn",
    "tag": "nacht-",
    "taub": "hören",
    "tod": "geburt",
    "schuldner": "gläubiger",
    "anstand": "unanständigkeit",
    "anständig": "unanständig",
    "laub": "immergrün",
    "entscheidung": "unentschlossenheit",
    "entscheidend": "unentschlossen",
    "ablehnen": "verbesserung",
    "verringern": "erhöhen, ansteigen",
    "verringert": "erhöht",
    "dekrement": "zuwachs",
    "niederlage": "sieg",
    "verteidigen": "strafrechtlich verfolgen",
    "beklagte": "kläger",
    "verteidigung": "strafverfolgung",
    "defensive": "beleidigend",
    "trotzig": "konform",
    "defizit": "führen",
    "definiert": "nicht definiert",
    "deflation": "inflation",
    "verzögern": "eilen",
    "verweilen": "eilen",
    "nachfrage": "liefern",
    "verweigern": "eingestehen",
    "ablehnen": "akzeptieren",
    "abhängig": "unabhängig",
    "anzahlung": "abheben",
    "abschreibung": "anerkennung",
    "deprimierend": "heiter",
    "absteigen": "aufsteigen",
    "nachkomme": "vorfahr",
    "abstammung": "aufstieg",
    "beschreibend": "präskriptiv",
    "wünschenswert": "unerwünscht",
    "verzweiflung": "hoffnung",
    "verzweifelt": "hoffnung",
    "zerstört": "konserviert",
    "ablösen": "anfügen",
    "übertragung": "evolution",
    "abweichen": "gleich",
    "ungleich": "gleich",
    "unterschied": "gleichheit",
    "schwer": "einfach",
    "unruhig": "einfach",
    "schwierigkeit": "leichtigkeit",
    "fleißig": "fahrlässig",
    "verdünnung": "konzentration",
    "verteilung": "konzentration",
    "verminderung": "augmentation",
    "dreckig": "reinigen",
    "unrein": "reinigen",
    "deaktivieren": "aktivieren",
    "nachteil": "vorteil",
    "nicht zustimmen": "zustimmen",
    "unangenehm": "angenehm",
    "uneinigkeit": "zustimmung",
    "verschwinden": "aussehen",
    "missbilligung": "die genehmigung",
    "missbilligen": "genehmigen",
    "entwaffnen": "arm",
    "entladen": "gewinnen",
    "einbüßen": "anspruch",
    "beschwerden": "komfort",
    "trennen": "joint",
    "unzufriedenheit": "befriedigung",
    "einstellung": "bestand",
    "abbrechen": "fortsetzen",
    "diskontinuität": "kontinuität",
    "diskontinuierlich": "kontinuierlich",
    "entmutigen": "ermutigen",
    "entmutigung": "förderung",
    "lösen": "krawatte",
    "unehrlich": "ehrlich",
    "unehrlichkeit": "ehrlichkeit",
    "entehren": "ehre",
    "desinfizieren": "infizieren",
    "zerfallen": "integrieren",
    "disjunkt": "konjunktiv",
    "nicht gefallen": "geschmack",
    "entfernen": "hütte",
    "ungehorsam": "gehorsam",
    "ungehorsam": "gehorchen",
    "störung": "auftrag",
    "ungeordnet": "ordentlich",
    "unorganisiert": "organisiert",
    "unzufrieden": "glücklich",
    "widerlegen": "beweisen",
    "disqualifizieren": "qualifizieren",
    "anrüchig": "seriös",
    "verruf": "ruf",
    "respektlosigkeit": "respekt",
    "respektlos": "andächtig",
    "dissens": "zustimmung",
    "bärendienst": "bedienung",
    "unähnlich": "ähnlich",
    "dissonanz": "harmonie",
    "abbringen": "überzeugen",
    "distal": "proximal",
    "entfernt": "schließen",
    "öffnen": "geschlossen",
    "unterscheidbar": "nicht zu unterscheiden",
    "misstrauen": "vertrauen",
    "tagaktiv": "nachtaktiv",
    "divergieren": "konvergieren",
    "abweichungen": "konvergenz",
    "abweichend": "konvergent",
    "teilen": "vereinen",
    "einzeln": "multiplizieren",
    "geteilt": "vereinigt",
    "teilbar": "unteilbar",
    "inländisch": "ausländisch",
    "nativ": "ausländisch",
    "dominant": "untergeordnet",
    "ruhend": "aktiv",
    "ausgestorben": "vorhanden",
    "inaktiv": "aktiv",
    "passiv": "aktiv",
    "ruhig": "laut",
    "doppelt": "single",
    "mehrere": "single",
    "taube": "falke",
    "dramatisch": "lyrisch",
    "trocken": "nass",
    "sauer": "versüßen",
    "fällig": "unzulässig",
    "stumpf": "schärfen",
    "ebnen": "schärfen",
    "sterben": "im entstehen begriffen",
    "irdisch": "paradiesisch",
    "leichtigkeit": "schwere",
    "einfach": "verbindung",
    "ebbe": "tide",
    "exzenter": "konzentrisch",
    "gebildet": "ungebildet",
    "wirksam": "unwirksam",
    "effizienz": "ineffizienz",
    "effizient": "ineffizient",
    "austritt": "eintritt",
    "elastisch": "unelastisch",
    "berechtigt": "nicht förderfähig",
    "emotional": "zerebral",
    "empirisch": "theoretisch",
    "leere": "fülle",
    "leer": "voll",
    "dünn": "verdicken",
    "aktivieren": "deaktivieren",
    "ermutigen": "entmutigen",
    "förderung": "entmutigung",
    "ende": "anfang",
    "mitte": "früh",
    "endemisch": "kosmopolitisch",
    "provinziell": "kosmopolitisch",
    "energisch": "lethargisch",
    "erzwingen": "befreit",
    "engagieren": "lösen",
    "genießen": "leiden",
    "eingeben": "ausfahrt",
    "gleich": "ungleich",
    "gleichberechtigung": "ungleichheit",
    "äquatorial": "polar-",
    "gerecht": "ungerecht",
    "löschen": "entzünden",
    "gründen": "abschaffen",
    "ereignisreich": "ereignislos",
    "immergrün": "laub",
    "evolution": "übertragung",
    "ausschluss": "aufnahme",
    "befreit": "erzwingen",
    "ausatmen": "einatmen",
    "existent": "nicht existent",
    "ausfahrt": "eingeben",
    "erweitern": "eng",
    "erweitert": "vertrag abgeschlossen",
    "erweiterung": "beugung",
    "erwartet": "unerwartet",
    "teuer": "billig",
    "erfahren": "unerfahren",
    "export": "einführen",
    "ausdrücken": "lokal",
    "allgemeines": "spezifisch",
    "national": "international",
    "außen": "innere",
    "extern": "intern",
    "äußerlich": "im inneren",
    "extramural": "intramural",
    "außergewöhnlich": "gewöhnliche",
    "extrinsisch": "intrinsisch",
    "versagen": "vorbeigehen",
    "laufen": "stehen",
    "fehler": "erfolg",
    "messe": "unfair",
    "treu": "untreu",
    "fallen": "erhebt euch",
    "einstellen": "erhebt euch",
    "fehlbar": "unfehlbar",
    "fallend": "steigend",
    "lüge": "stand",
    "falschheit": "wahrheit",
    "ruhm": "schande",
    "familiär": "ungewohnt",
    "schick": "einfach",
    "fett": "dünn",
    "voll": "leer",
    "dick": "dünn",
    "verdicken": "dünn",
    "vater": "mutter",
    "fauna": "flora",
    "günstig": "ungünstig",
    "bundes": "einheitlich",
    "weiblich": "männlich",
    "feminin": "kastrieren",
    "weiblichkeit": "männlichkeit",
    "fruchtbar": "steril",
    "treue": "untreue",
    "zahl": "boden",
    "füllen": "leer",
    "finden": "verlieren",
    "fertig": "anfang",
    "halt": "anfang",
    "endlich": "unendlich",
    "feuer": "mieten",
    "beugung": "erweiterung",
    "schweben": "sinken",
    "quelle": "sinken",
    "flora": "fauna",
    "fokus": "verwischen",
    "feind": "freund",
    "falten": "entfalten",
    "folgen": "vorausgehen",
    "gelingen": "vorausgehen",
    "anhänger": "führer",
    "torheit": "weisheit",
    "töricht": "weise",
    "fuß": "kopf",
    "schwanz": "kopf",
    "verbieten": "legalisieren",
    "vordergrund": "hintergrund",
    "ausländisch": "nativ",
    "vergessen": "merken",
    "versöhnlich": "unversöhnlich",
    "formalismus": "nachahmung",
    "glücklich": "unzufrieden",
    "nach vorne": "umkehren",
    "foul": "messe",
    "unfair": "messe",
    "gefunden": "hat verloren",
    "brüderlich": "identisch",
    "einfrieren": "kochen",
    "häufig": "selten",
    "freund": "feind",
    "kopf": "schwanz",
    "funktionell": "organisch",
    "anorganisch": "organisch",
    "gasförmig": "solide",
    "hohl": "solide",
    "versammeln": "verbreitung",
    "allgemeinheit": "besonderheit",
    "großzügig": "geizig",
    "mädchen": "junge",
    "gut": "böse",
    "güte": "schlechtigkeit",
    "schrittweise": "plötzlich",
    "dankbar": "undankbar",
    "größer": "geringer",
    "grün": "reif",
    "brutto": "netz",
    "boden": "zahl",
    "schuld": "unschuld",
    "schuldig": "unschuldig",
    "glück": "unglück",
    "härte": "weichheit",
    "lautstärke": "weichheit",
    "schärfe": "weichheit",
    "harmonie": "dissonanz",
    "hass": "liebe",
    "hasserfüllt": "liebenswert",
    "falke": "taube",
    "gesund": "wahnsinnig",
    "hören": "taub",
    "hitze": "cool",
    "paradiesisch": "irdisch",
    "heterogenität": "homogenität",
    "verbergen": "show",
    "mieten": "feuer",
    "schlagen": "fräulein",
    "heilig": "entweihen",
    "homogenität": "heterogenität",
    "homolog": "analog",
    "homosexuell": "bisexuell",
    "ehrlich": "unehrlich",
    "ehrlichkeit": "unehrlichkeit",
    "ehre": "entehren",
    "hoffnung": "verzweiflung",
    "hoffnungsvoll": "hoffnungslos",
    "hoffnungslos": "hoffnungsvoll",
    "horizontal": "vertikal",
    "feindlich": "freundlich",
    "unfreundlich": "freundlich",
    "heiß": "kalt",
    "demütigen": "stolz",
    "demut": "stolz",
    "hungrig": "durstig",
    "identisch": "brüderlich",
    "leerlauf": "arbeit",
    "magmatisch": "wässrig",
    "entzünden": "löschen",
    "ignorieren": "beachten",
    "illegal": "legal",
    "rechtswidrigkeit": "rechtmäßigkeit",
    "unleserlich": "lesbar",
    "unlogisch": "logisch",
    "nachahmung": "formalismus",
    "immateriell": "material",
    "unreife": "reife",
    "unermesslich": "messbar",
    "unmoralisch": "moral-",
    "unmoral": "moral",
    "unsterblich": "sterblich",
    "unsterblichkeit": "mortalität",
    "unveränderlich": "veränderbar",
    "unparteilichkeit": "parteilichkeit",
    "unpassierbar": "befahrbar",
    "ungeduld": "die geduld",
    "ungeduldig": "geduldig",
    "unmerklich": "wahrnehmbar",
    "unvollkommenheit": "perfektion",
    "undurchlässig": "durchlässig",
    "unzulässig": "fällig",
    "unpersönlich": "persönlich",
    "unhöflich": "höflich",
    "einführen": "export",
    "wichtig": "unwichtig",
    "unmöglichkeit": "möglichkeit",
    "impotent": "stark",
    "unwahrscheinlich": "wahrscheinlich",
    "verbessert": "unverbessert",
    "verbesserung": "ablehnen",
    "unklug": "umsichtig",
    "verunreinigung": "reinheit",
    "unfähigkeit": "kapazität",
    "nicht zugänglich": "zugänglich",
    "ungenau": "genau",
    "untätigkeit": "aktion",
    "inaktivität": "aktivität",
    "unzureichend": "ausreichend",
    "unbelebt": "animieren",
    "unaufmerksamkeit": "beachtung",
    "unverständlich": "verständlich",
    "unfähig": "fähig",
    "geneigt": "horizontal",
    "vertikal": "horizontal",
    "aufnahme": "ausschluss",
    "inkohärent": "kohärent",
    "unvereinbar": "kompatibel",
    "inkompetenz": "kompetenz",
    "inkompetent": "kompetent",
    "unvollständigkeit": "vollständigkeit",
    "rücksichtslos": "rücksichtsvoll",
    "inkonsistenz": "konsistenz",
    "unauffällig": "auffällig",
    "ungünstig": "günstig",
    "erhöhen, ansteigen": "verringern",
    "erhöht": "verringert",
    "zuwachs": "dekrement",
    "unheilbar": "heilbar",
    "unanständigkeit": "anstand",
    "unanständig": "anständig",
    "unentschlossenheit": "entscheidung",
    "unentschlossen": "entscheidend",
    "unabhängig": "abhängig",
    "nicht zu unterscheiden": "unterscheidbar",
    "unteilbar": "teilbar",
    "innen": "draussen",
    "unwirksam": "operative",
    "ineffizienz": "effizienz",
    "ineffizient": "effizient",
    "unelastisch": "elastisch",
    "nicht förderfähig": "berechtigt",
    "ungleichheit": "gleichberechtigung",
    "ungerecht": "gerecht",
    "unerfahren": "erfahren",
    "unfehlbar": "fehlbar",
    "schande": "ruhm",
    "infizieren": "desinfizieren",
    "minderwertig": "überlegen",
    "minderwertigkeit": "überlegenheit",
    "untreue": "treue",
    "unendlich": "endlich",
    "inflation": "deflation",
    "informiert": "nicht informiert",
    "selten": "häufig",
    "eintritt": "austritt",
    "bewohnt": "unbewohnt",
    "einatmen": "ausatmen",
    "ungerechtigkeit": "gerechtigkeit",
    "inland": "küsten",
    "unschuld": "schuld",
    "unschuldig": "schuldig",
    "harmlos": "schädlich",
    "wahnsinnig": "gesund",
    "wahnsinn": "vernunft",
    "unsicherheit": "sicherheit",
    "bedeutungslosigkeit": "bedeutung",
    "unbedeutend": "von bedeutung",
    "unlöslich": "löslich",
    "insolvenz": "zahlungsfähigkeit",
    "zahlungsunfähig": "lösungsmittel",
    "instabilität": "stabilität",
    "instrumental": "vokal",
    "insuffizienz": "suffizienz",
    "ungenügend": "ausreichend",
    "integrieren": "zerfallen",
    "integration": "trennung",
    "intelligenz": "dummheit",
    "verständlich": "unverständlich",
    "beabsichtigt": "unbeabsichtigt",
    "absichtlich": "unbeabsichtigt",
    "interessiert": "uninteressiert",
    "interessant": "uninteressant",
    "innere": "außen",
    "mittlere": "terminal",
    "intern": "extern",
    "im inneren": "äußerlich",
    "international": "national",
    "lokal": "allgemeines",
    "intoleranz": "toleranz",
    "intolerant": "tolerant",
    "hartnäckig": "lenkbar",
    "intramural": "extramural",
    "intrinsisch": "extrinsisch",
    "unsichtbarkeit": "sichtweite",
    "unsichtbar": "sichtbar",
    "unfreiwillig": "freiwillig",
    "irrational": "rational",
    "irregulär": "regulär",
    "unregelmäßigkeit": "regelmäßigkeit",
    "irrelevant": "relevant",
    "unverantwortlich": "verantwortlich",
    "problem": "erinnern",
    "joint": "trennen",
    "freude": "trauer",
    "froh": "traurig",
    "junior": "senior",
    "gerechtigkeit": "ungerechtigkeit",
    "jugendlich": "erwachsene",
    "kern": "kern",
    "nett": "nicht nett",
    "könig": "königin",
    "laien": "klerus",
    "spät": "früh",
    "lachen": "schrei",
    "rechtmäßig": "ungesetzlich",
    "lax": "tempus",
    "entspannt": "tempus",
    "laie": "geistliche",
    "führen": "defizit",
    "führer": "anhänger",
    "verlassen": "ankommen",
    "links": "center",
    "legal": "illegal",
    "rechtmäßigkeit": "rechtswidrigkeit",
    "legalisieren": "verbieten",
    "lesbar": "unleserlich",
    "verleihen": "leihen",
    "darlehensgeber": "kreditnehmer",
    "verlängern": "verkürzen",
    "geringer": "haupt",
    "lethargisch": "energisch",
    "niveau": "erziehen",
    "niedriger": "erziehen",
    "liberale": "konservativ",
    "ausbeute": "stand",
    "licht": "dunkel",
    "geschmack": "nicht gefallen",
    "begrenzt": "unbegrenzt",
    "geradlinig": "sicherheit",
    "flüssigkeit": "gasförmig",
    "solide": "hohl",
    "spezifisch": "allgemeines",
    "lage": "studio",
    "sperren": "freischalten",
    "hütte": "entfernen",
    "logisch": "unlogisch",
    "lange": "kurz",
    "hoch": "kurz",
    "verlieren": "finden",
    "verlust": "gewinnen",
    "hat verloren": "gefunden",
    "liebenswert": "hasserfüllt",
    "liebe": "hass",
    "glücklich": "unglücklich",
    "lyrisch": "dramatisch",
    "haupt": "geringer",
    "mehrheit": "minderheit",
    "machen": "unterbrechung",
    "reparatur": "unterbrechung",
    "männlich": "feminin",
    "verleumden": "gutartig",
    "maligne": "gutartig",
    "handbuch": "automatisch",
    "markiert": "unmarkiert",
    "verheiratet": "unverheiratet",
    "kastrieren": "feminin",
    "männlichkeit": "weiblichkeit",
    "maske": "entlarven",
    "material": "immateriell",
    "mütterlich": "väterlicherseits",
    "reife": "unreife",
    "maximal": "minimum",
    "messbar": "unermesslich",
    "geistig": "physisch",
    "barmherzig": "gnadenlos",
    "gnadenlos": "barmherzig",
    "militär-": "zivilist",
    "verstand": "vergessen",
    "merken": "vergessen",
    "minimum": "maximal",
    "minderheit": "mehrheit",
    "missverständnis": "konzeption",
    "fräulein": "schlagen",
    "molar": "molekular",
    "molekular": "molar",
    "moral-": "unmoralisch",
    "moral": "unmoral",
    "sterblich": "unsterblich",
    "mortalität": "unsterblichkeit",
    "mutter": "vater",
    "multiplizieren": "einzeln",
    "vereinen": "teilen",
    "veränderlich": "unveränderlich",
    "nadir": "zenit",
    "eng": "erweitern",
    "im entstehen begriffen": "sterben",
    "negativ": "neutral",
    "fahrlässig": "fleißig",
    "neffe": "nichte",
    "netz": "brutto",
    "nichte": "neffe",
    "nacht-": "tag",
    "nachtaktiv": "tagaktiv",
    "nominal": "echt",
    "unwirklich": "echt",
    "nicht existent": "existent",
    "normal": "abnormal",
    "beachten": "ignorieren",
    "schädlich": "harmlos",
    "numerisch": "verbal",
    "gehorsam": "ungehorsam",
    "gehorsam": "ungehorsam",
    "gehorchen": "ungehorsam",
    "zielsetzung": "subjektive",
    "obligatorisch": "wahlweise",
    "schräg": "aufrecht",
    "opazität": "transparenz",
    "belegt": "unbesetzt",
    "delikt": "verteidigung",
    "strafverfolgung": "verteidigung",
    "beleidigend": "defensive",
    "offiziell": "inoffiziell",
    "offenheit": "nähe",
    "operative": "unwirksam",
    "entgegengesetzt": "ungestört",
    "gegenteil": "wechseln",
    "optimismus": "pessimismus",
    "optimist": "pessimist",
    "wahlweise": "obligatorisch",
    "oral": "anal",
    "auftrag": "störung",
    "ordentlich": "ungeordnet",
    "gewöhnliche": "außergewöhnlich",
    "organisch": "anorganisch",
    "organisiert": "unorganisiert",
    "orthodox": "unorthodox",
    "draussen": "innen",
    "überschätzen": "unterschätzen",
    "overhead": "oberfläche",
    "offen": "verdeckt",
    "pack": "auspacken",
    "schmerzlich": "schmerzlos",
    "schmerzlos": "schmerzlich",
    "parallel": "schräg",
    "aufrecht": "schräg",
    "elternteil": "kind",
    "parteilichkeit": "unparteilichkeit",
    "besonderheit": "allgemeinheit",
    "teilweise": "ganz",
    "befahrbar": "unpassierbar",
    "vorbeigehen": "laufen",
    "stehen": "laufen",
    "vergangenheit": "zukunft",
    "geschenk": "abwesend",
    "väterlicherseits": "mütterlich",
    "die geduld": "ungeduld",
    "geduldig": "ungeduldig",
    "bevormunden": "boykott",
    "frieden": "krieg",
    "elfmeter": "belohnung",
    "wahrnehmbar": "unmerklich",
    "perfektion": "unvollkommenheit",
    "durchlässig": "undurchlässig",
    "freizügig": "präventiv",
    "erlauben": "verbieten",
    "persönlich": "unpersönlich",
    "überzeugen": "abbringen",
    "pessimismus": "optimismus",
    "pessimist": "optimist",
    "physisch": "geistig",
    "kläger": "beklagte",
    "zufrieden": "unzufrieden",
    "plural-": "singular",
    "polar-": "äquatorial",
    "höflich": "unhöflich",
    "beliebt": "unpopulär",
    "porosität": "solidität",
    "möglichkeit": "unmöglichkeit",
    "hintere": "anterior",
    "stark": "schwach",
    "potenzial": "tatsächlich",
    "armut": "reichtum",
    "mächtig": "machtlos",
    "machtlos": "mächtig",
    "loben": "kritisieren",
    "vorausgehen": "gelingen",
    "präfix": "suffix",
    "vorbereitung": "auflösung",
    "bereit": "unvorbereitet",
    "präskriptiv": "beschreibend",
    "gegenwart": "abwesenheit",
    "konserviert": "zerstört",
    "präventiv": "freizügig",
    "primär": "sekundär",
    "privatgelände": "öffentlichkeit",
    "privat": "öffentlich",
    "wahrscheinlich": "unwahrscheinlich",
    "produktiv": "unproduktiv",
    "entweihen": "heilig",
    "professionel": "amateur",
    "fortschritt": "regress",
    "progressiv": "regressiv",
    "prospektiv": "retrospektive",
    "geschützt": "ungeschützt",
    "stolz": "demütigen",
    "beweisen": "widerlegen",
    "proximal": "distal",
    "nahe": "letztendlich",
    "umsichtig": "unklug",
    "öffentlichkeit": "privatgelände",
    "öffentlich": "privat",
    "veröffentlicht": "unveröffentlicht",
    "ziehen": "drücken",
    "pünktlichkeit": "verspätung",
    "säuberung": "rehabilitieren",
    "reinheit": "verunreinigung",
    "drücken": "ziehen",
    "qualifizieren": "disqualifizieren",
    "königin": "könig",
    "frage": "antworten",
    "fraglich": "unbestreitbar",
    "schnell": "langsam",
    "erziehen": "niedriger",
    "rational": "irrational",
    "echt": "unwirklich",
    "realistisch": "unrealistisch",
    "beruhigen": "sorge",
    "erinnern": "problem",
    "aufzeichnung": "löschen",
    "refrain": "handlung",
    "sich weigern": "akzeptieren",
    "regress": "fortschritt",
    "regressiv": "progressiv",
    "regulär": "irregulär",
    "regelmäßigkeit": "unregelmäßigkeit",
    "reguliert": "unreguliert",
    "rehabilitieren": "säuberung",
    "ablehnung": "annahme",
    "verjüngen": "alter",
    "verbunden": "nicht verwandt",
    "relativ": "absolut",
    "relevant": "irrelevant",
    "zuverlässig": "unzuverlässig",
    "religiös": "weltlich",
    "abstoßung": "attraktion",
    "seriös": "anrüchig",
    "ruf": "verruf",
    "widerstehen": "kapitulation",
    "auflösung": "vorbereitung",
    "respekt": "respektlosigkeit",
    "respektvoll": "respektlos",
    "verantwortlich": "unverantwortlich",
    "zurückhaltend": "hemmungslos",
    "beschränkt": "uneingeschränkt",
    "retrospektive": "prospektiv",
    "andächtig": "respektlos",
    "umkehrung": "bejahung",
    "belohnung": "elfmeter",
    "reiten": "gehen",
    "reif": "grün",
    "erhebt euch": "einstellen",
    "steigend": "fallend",
    "rotor": "stator",
    "rauheit": "glätte",
    "runden": "platz",
    "gerundet": "winkel",
    "ländlich": "städtisch",
    "eilen": "verweilen",
    "traurig": "froh",
    "traurigkeit": "glück",
    "unglück": "glück",
    "sicher": "gefährlich",
    "gleichheit": "unterschied",
    "vernunft": "wahnsinn",
    "befriedigung": "unzufriedenheit",
    "bohnenkraut": "unsäglich",
    "knapp": "reichlich",
    "knappheit": "fülle",
    "wissenschaftlich": "unwissenschaftlich",
    "gewissenhaft": "skrupellos",
    "sekundär": "primär",
    "weltlich": "religiös",
    "trennung": "union",
    "egoistisch": "selbstlos",
    "verkaufen": "kaufen",
    "senior": "junior",
    "septisch": "antiseptikum",
    "bedienung": "bärendienst",
    "beglichen": "verunsichert",
    "schärfen": "ebnen",
    "kurz": "hoch",
    "verkürzen": "verlängern",
    "schreien": "flüstern",
    "show": "verbergen",
    "schrumpfen": "strecken",
    "seite": "unterseite",
    "oben": "unterseite",
    "von bedeutung": "unbedeutend",
    "ähnlich": "unähnlich",
    "vereinfachen": "komplizieren",
    "single": "mehrere",
    "singular": "plural-",
    "sinken": "quelle",
    "schwester": "bruder",
    "schlaf": "aufwachen",
    "langsam": "schnell",
    "klein": "groß",
    "glätte": "rauheit",
    "weichheit": "schärfe",
    "solidität": "porosität",
    "löslich": "unlöslich",
    "zahlungsfähigkeit": "insolvenz",
    "lösungsmittel": "zahlungsunfähig",
    "sohn": "tochter",
    "trauer": "freude",
    "gesprochen": "geschrieben",
    "ungeschrieben": "geschrieben",
    "sporadisch": "kontinuierlich",
    "verbreitung": "versammeln",
    "platz": "runden",
    "stabilität": "instabilität",
    "stabil": "instabil",
    "stand": "ausbeute",
    "stator": "rotor",
    "bleibe": "bewegung",
    "stetig": "unsicher",
    "steil": "schrittweise",
    "plötzlich": "schrittweise",
    "steril": "fruchtbar",
    "versteifen": "lösen",
    "geizig": "großzügig",
    "stürmisch": "ruhe",
    "gerade": "gebogen",
    "begradigen": "biege",
    "fremder": "bekanntschaft",
    "stärke": "die schwäche",
    "strecken": "schrumpfen",
    "studio": "lage",
    "dummheit": "intelligenz",
    "subjektive": "zielsetzung",
    "untergeordnet": "dominant",
    "anschließend": "antecedent",
    "substantiv": "adjektiv",
    "subtrahieren": "hinzufügen",
    "subtraktion": "zusatz",
    "erfolgreich": "erfolglos",
    "erfolg": "fehler",
    "erliegen": "überleben",
    "leiden": "genießen",
    "suffizienz": "insuffizienz",
    "ausreichend": "ungenügend",
    "suffix": "präfix",
    "sonnenaufgang": "sonnenuntergang",
    "sonnenuntergang": "sonnenaufgang",
    "überlegen": "minderwertig",
    "überlegenheit": "minderwertigkeit",
    "liefern": "nachfrage",
    "unterstützt": "nicht unterstützt",
    "oberfläche": "overhead",
    "kapitulation": "widerstehen",
    "überleben": "erliegen",
    "süss": "sauer",
    "nass": "trocken",
    "versüßen": "sauer",
    "symmetrie": "asymmetrie",
    "sympathisch": "unsympathisch",
    "synergistisch": "antagonistisch",
    "synthese": "analyse",
    "synthetik": "analytisch",
    "verspätung": "pünktlichkeit",
    "geschmackvoll": "geschmacklos",
    "lecker": "geschmacklos",
    "geschmacklos": "lecker",
    "zärtlich": "zäh",
    "tempus": "entspannt",
    "terminal": "mittlere",
    "theismus": "atheismus",
    "theoretisch": "empirisch",
    "durstig": "hungrig",
    "nachdenklich": "gedankenlos",
    "gedankenlos": "nachdenklich",
    "sparsam": "verschwenderisch",
    "tide": "ebbe",
    "krawatte": "lösen",
    "schüchtern": "fett gedruckt",
    "schüchternheit": "mut",
    "toleranz": "intoleranz",
    "tolerant": "intolerant",
    "gezahnt": "zahnlos",
    "zahnlos": "gezahnt",
    "berührt": "unberührt",
    "zäh": "zärtlich",
    "lenkbar": "hartnäckig",
    "tragödie": "komödie",
    "ausgebildet": "untrainiert",
    "vertrauen": "misstrauen",
    "wahrheit": "falschheit",
    "hässlichkeit": "schönheit",
    "hässlich": "schön",
    "letztendlich": "nahe",
    "inakzeptabel": "akzeptabel",
    "unbestätigt": "bestätigt",
    "unverändert": "geändert",
    "eindeutig": "mehrdeutig",
    "unbewaffnet": "bewaffnet",
    "nicht autorisiert": "autorisiert",
    "unausgeglichen": "ausgewogen",
    "unglaube": "glauben",
    "ungebunden": "gebunden",
    "unzerbrechlich": "zerbrechlich",
    "ungebrochen": "gebrochen",
    "onkel": "tante",
    "ungewöhnlich": "gewöhnlich",
    "unbekümmert": "besorgt",
    "unverbunden": "in verbindung gebracht",
    "bewusstlosigkeit": "bewusstsein",
    "verfassungswidrig": "konstitutionelle",
    "unkonventionell": "konventionell",
    "nicht überzeugt": "überzeugt",
    "aufdecken": "abdeckung",
    "ungeschnitten": "schnitt",
    "nicht definiert": "definiert",
    "unterschätzen": "überschätzen",
    "unerwünscht": "wünschenswert",
    "ungebildet": "gebildet",
    "ereignislos": "ereignisreich",
    "unerwartet": "erwartet",
    "untreu": "treu",
    "ungewohnt": "familiär",
    "entfalten": "falten",
    "unversöhnlich": "versöhnlich",
    "unglücklich": "glücklich",
    "undankbar": "dankbar",
    "ungesund": "gesund",
    "unheilig": "heilig",
    "unwichtig": "wichtig",
    "unverbessert": "verbessert",
    "nicht informiert": "informiert",
    "unbewohnt": "bewohnt",
    "unbeabsichtigt": "absichtlich",
    "uninteressiert": "interessiert",
    "uninteressant": "interessant",
    "union": "trennung",
    "einheitlich": "bundes",
    "vereinigt": "geteilt",
    "nicht nett": "nett",
    "ungesetzlich": "rechtmäßig",
    "unbegrenzt": "begrenzt",
    "freischalten": "sperren",
    "unmarkiert": "markiert",
    "unverheiratet": "verheiratet",
    "entlarven": "maske",
    "unbesetzt": "belegt",
    "inoffiziell": "offiziell",
    "ungestört": "entgegengesetzt",
    "unorthodox": "orthodox",
    "auspacken": "pack",
    "unpopulär": "beliebt",
    "unvorbereitet": "bereit",
    "unproduktiv": "produktiv",
    "ungeschützt": "geschützt",
    "unveröffentlicht": "veröffentlicht",
    "unbestreitbar": "fraglich",
    "unrealistisch": "realistisch",
    "unreguliert": "reguliert",
    "nicht verwandt": "verbunden",
    "unzuverlässig": "zuverlässig",
    "hemmungslos": "zurückhaltend",
    "uneingeschränkt": "beschränkt",
    "unsäglich": "bohnenkraut",
    "unwissenschaftlich": "wissenschaftlich",
    "skrupellos": "gewissenhaft",
    "selbstlos": "egoistisch",
    "verunsichert": "beglichen",
    "instabil": "stabil",
    "unsicher": "stetig",
    "erfolglos": "erfolgreich",
    "nicht unterstützt": "unterstützt",
    "unsympathisch": "sympathisch",
    "unberührt": "berührt",
    "untrainiert": "ausgebildet",
    "enthüllen": "schleier",
    "unvorsichtig": "vorsichtig",
    "widerwillig": "bereitwillig",
    "unwilligkeit": "bereitschaft",
    "abwickeln": "wind",
    "unwürdig": "würdig",
    "städtisch": "ländlich",
    "gewöhnlich": "ungewöhnlich",
    "wertvoll": "wertlos",
    "schleier": "enthüllen",
    "verbal": "numerisch",
    "sieg": "niederlage",
    "tugendhaft": "böse",
    "sichtweite": "unsichtbarkeit",
    "sichtbar": "unsichtbar",
    "vokal": "konsonant",
    "freiwillig": "unfreiwillig",
    "aufwachen": "schlaf",
    "gehen": "reiten",
    "schwinden": "wachs",
    "krieg": "frieden",
    "vorsichtig": "unvorsichtig",
    "abfall": "sparen",
    "verschwenderisch": "sparsam",
    "wachs": "schwinden",
    "schwach": "stark",
    "die schwäche": "stärke",
    "reichtum": "armut",
    "schwerelos": "gewichtig",
    "gewichtig": "schwerelos",
    "flüstern": "schreien",
    "weiß": "schwarz",
    "ganz": "teilweise",
    "breit": "eng",
    "bereitwillig": "widerwillig",
    "bereitschaft": "unwilligkeit",
    "wind": "abwickeln",
    "weisheit": "torheit",
    "weise": "töricht",
    "abheben": "anzahlung",
    "sorge": "beruhigen",
    "wertlos": "wertvoll",
    "würdig": "unwürdig",
    "geschrieben": "ungeschrieben",
    "jung": "alt",
    "zenit": "nadir",
}



"""
@author: alfonso.semeraro@unito.it

Baselines are in the format [emo_combinations, weights] where

emo_combinations = [['joy'], ['joy', 'trust'], ['joy', 'trust', 'fear'] ...]
weights = [123521, 1242, 212, ...]

"""

import emoatlas.textloader as _load_object
from collections import Counter
import pickle


def _make_baseline(
    baseline=None,
    tagger=None,
    language="english",
    emojis_dict={},
    idiomatic_tokens={},
    emotion_lexicon=None,
    convert_emojis=True,
):

    if baseline:
        # extract all words from the input baseline
        wordlist = _load_object(
            baseline=baseline,
            language=language,
            tagger=tagger,
            emojis_dict=emojis_dict,
            convert_emojis=convert_emojis,
            idiomatic_tokens=idiomatic_tokens,
        )

        # check into the lexicon the emotions associated
        emotions = [emotion_lexicon[w] for w in wordlist]

        if not emotions:
            raise ValueError(
                "Baseline has no emotions. Fallback to the default baseline."
            )
    else:
        # use the emotion lexicon as baseline
        emotions = list(emotion_lexicon.values())

    # count
    baseline_distr = dict(Counter(map(tuple, emotions)))
    # two lists: items and weights
    baseline_distr = [
        [list(k) for k in baseline_distr.keys()],
        list(baseline_distr.values()),
    ]

    return baseline_distr


def _load_lookup_table(language="english"):

    try:
        with open("baseline_tables/{}_baseline.dict".format(language), "rb") as rb:
            lookup = pickle.load(rb)
    except:
        lookup = {}

    return lookup
